@@ -1,4 +1,4 @@
-# Copyright 2013-2020 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2013-2021 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -24,10 +24,7 @@ from reahl.tofu import Fixture, set_up, tear_down, scope, uses
 
 from reahl.component.shelltools import Executable
 from reahl.webdev.webserver import ReahlWebServer
-from reahl.web.egg import WebConfig
-from reahl.web.fw import UserInterface
-from reahl.webdeclarative.webdeclarative import UserSession, PersistedException, PersistedFile, UserInput
-from reahl.domain.systemaccountmodel import SystemAccountConfig
+
 
 from reahl.dev.fixtures import ReahlSystemSessionFixture
 
@@ -61,7 +58,7 @@ class WebServerFixture(Fixture):
     """
 
     def new_reahl_server(self):
-        return ReahlWebServer(self.reahl_system_fixture.config, 8000)
+        return ReahlWebServer(self.reahl_system_fixture.config)
 
     @property
     def web_driver(self):
